==> dpsrc.02_25_2008.tar.gz: aqua_src.f <==
      SUBROUTINE AQINIT(NPLOT,NUMHPP,NUMVPP,IRED,IGREEN,IBLUE,MAXCLR)
C
      INTEGER IRED(*)
      INTEGER IGREEN(*)
      INTEGER IBLUE(*)
C
      CHARACTER*4 IFEEDB
      CHARACTER*4 IPRINT
      CHARACTER*240 ICOUT
C
      COMMON /MACH/IRD,IPR,CPUMIN,CPUMAX,NUMBPC,NUMCPW,NUMBPW
      COMMON /PRINT/IFEEDB,IPRINT
      COMMON /TEXTOU/ICOUT,NCOUT,ILOUT
C
      WRITE(ICOUT,999)
  999 FORMAT(1X)
      CALL DPWRST('XXX','BUG ')
      WRITE(ICOUT,101)
  101 FORMAT('THE AQUA DEVICE DRIVER IS NOT CURRENTLY SUPPORTED ',
     1       'FOR THIS INSTALLATION.')
      CALL DPWRST('XXX','BUG ')
C
      RETURN
      END
      SUBROUTINE AQERAS(NPLOT,ANUMHP,ANUMVP,IBACK)
      INTEGER NPLOT
      INTEGER ANUMHP
      INTEGER ANUMVP
      INTEGER IBACK
      RETURN
      END
      SUBROUTINE AQEND()
      RETURN
      END
      SUBROUTINE AQREND()
      RETURN
      END
      SUBROUTINE AQDRAW(X,Y,NPTS,ICAP)
C
      REAL X(*)
      REAL Y(*)
C
      RETURN
      END
      SUBROUTINE AQMOVE(X,Y)
C
      REAL X
      REAL Y
C
      RETURN
      END
      SUBROUTINE AQSECO(INDEX)
      RETURN
      END
      SUBROUTINE AQSEPA(XPATT,NPATT,PTHICK,IOPT)
      REAL XPATT(*)
      RETURN
      END
      SUBROUTINE AQSESI(PHEIGH)
      RETURN
      END
      SUBROUTINE AQPOIN(IX,IY,JCOL)
      INTEGER IX(*), IY(*), JCOL
      RETURN
      END
      SUBROUTINE AQRECT(IX1,IY1,IX2,IY2)
      RETURN
      END
      SUBROUTINE AQRGFL(X,Y,NPTS)
      REAL X(*)
      REAL Y(*)
      RETURN
      END
      SUBROUTINE AQTXTV(ISTRNG,IXPOS,IYPOS,IJUSTH,IJUSTV,IADE,IERROR)
      INTEGER ISTRNG(*)
      INTEGER IADE(*)
      RETURN
      END
      SUBROUTINE AQTXTH(ISTRNG,IXPOS,IYPOS,IJUSTH,IJUSTV,IADE,IERROR)
      INTEGER ISTRNG(*)
      INTEGER IADE(*)
      RETURN
      END
      SUBROUTINE AQRDLO(X,Y,IERR)
      INTEGER X
      INTEGER Y
      INTEGER IERR
      RETURN
      END

==> dpsrc_2009_08_21.tar.gz: aqua_src.f <==
      SUBROUTINE AQINIT(NPLOT,NUMHPP,NUMVPP,IRED,IGREEN,IBLUE,MAXCLR)
C
      INTEGER IRED(*)
      INTEGER IGREEN(*)
      INTEGER IBLUE(*)
C
      CHARACTER*4 IFEEDB
      CHARACTER*4 IPRINT
      CHARACTER*240 ICOUT
C
      COMMON /MACH/IRD,IPR,CPUMIN,CPUMAX,NUMBPC,NUMCPW,NUMBPW
      COMMON /PRINT/IFEEDB,IPRINT
      COMMON /TEXTOU/ICOUT,NCOUT,ILOUT
C
      WRITE(ICOUT,999)
  999 FORMAT(1X)
      CALL DPWRST('XXX','BUG ')
      WRITE(ICOUT,101)
  101 FORMAT('THE AQUA DEVICE DRIVER IS NOT CURRENTLY SUPPORTED ',
     1       'FOR THIS INSTALLATION.')
      CALL DPWRST('XXX','BUG ')
C
      RETURN
      END
      SUBROUTINE AQERAS(NPLOT,ANUMHP,ANUMVP,IBACK)
      INTEGER NPLOT
      INTEGER ANUMHP
      INTEGER ANUMVP
      INTEGER IBACK
      RETURN
      END
      SUBROUTINE AQEND()
      RETURN
      END
      SUBROUTINE AQREND()
      RETURN
      END
      SUBROUTINE AQDRAW(X,Y,NPTS,ICAP)
C
      REAL X(*)
      REAL Y(*)
C
      RETURN
      END
      SUBROUTINE AQMOVE(X,Y)
C
      REAL X
      REAL Y
C
      RETURN
      END
      SUBROUTINE AQSECO(INDEX)
      RETURN
      END
      SUBROUTINE AQSEC2(AVAL1,AVAL2,AVAL3)
      RETURN
      END
      SUBROUTINE AQSEPA(XPATT,NPATT,PTHICK,IOPT)
      REAL XPATT(*)
      RETURN
      END
      SUBROUTINE AQSESI(PHEIGH)
      RETURN
      END
      SUBROUTINE AQPOIN(IX,IY,IRED,IGREEN,IBLUE)
      INTEGER IX(*), IY(*), JCOL
      RETURN
      END
      SUBROUTINE AQRECT(IX1,IY1,IX2,IY2)
      RETURN
      END
      SUBROUTINE AQRGFL(X,Y,NPTS)
      REAL X(*)
      REAL Y(*)
      RETURN
      END
      SUBROUTINE AQTXTV(ISTRNG,IXPOS,IYPOS,IJUSTH,IJUSTV,IADE,IERROR)
      INTEGER ISTRNG(*)
      INTEGER IADE(*)
      RETURN
      END
      SUBROUTINE AQTXTH(ISTRNG,IXPOS,IYPOS,IJUSTH,IJUSTV,IADE,IERROR)
      INTEGER ISTRNG(*)
      INTEGER IADE(*)
      RETURN
      END
      SUBROUTINE AQRDLO(X,Y,IERR)
      INTEGER X
      INTEGER Y
      INTEGER IERR
      RETURN
      END
